# Use bundled deps as we don't ship the exact right versions for all the
# required rust libraries
%global bundled_rust_deps 1

%define api_version	2
%define lib_major	2
%define gir_major	2.0
%define lib_name	%mklibname rsvg %{api_version} %{lib_major}
%define libnamedev	%mklibname -d rsvg %{api_version}
%define girname		%mklibname rsvg-gir %{gir_major}

# mozilla plugin requires xulruuner 1.8 not 1.9
%define build_mozilla	0

%define url_ver	%{lua: ver = rpm.expand("%{version}"); majmin, count1 = string.gsub(ver, "^([0123456789]+%.[0123456789]+).*", "%1", 1); if count1 == 0 then print(ver); return; end; maj, count2 = string.gsub(majmin, "^([0123456789]+).*", "%1", 1); if count2 == 0 then print(majmin) elseif tonumber(majmin) < 40 then print(majmin) else print(maj) end}

Name:		librsvg
Summary:	Raph's SVG library
Version:	2.56.0
%define subrel 1
Release: 	%mkrel 1
License: 	LGPLv2+ and GPLv2+
Group:		Graphics/Utilities
URL: 		https://wiki.gnome.org/action/show/Projects/LibRsvg
Source0: 	https://download.gnome.org/sources/%{name}/%{url_ver}/%{name}-%{version}.tar.xz
Source2:	vendor.tar.zst
Source3:	cargo_config
Patch0:		39e253981df34f19be1af3e7cc75948d46102bdf.patch
%if 0%{?bundled_rust_deps}
BuildRequires:	cargo
BuildRequires:	rust
%else
BuildRequires:	rust-packaging
%endif
BuildRequires:	pkgconfig(cairo) >= 1.15.10
BuildRequires:	pkgconfig(cairo-png)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(gdk-pixbuf-2.0)
BuildRequires:	pkgconfig(gio-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(pangocairo)
BuildRequires:	pkgconfig(pangoft2)
BuildRequires:	pkgconfig(gobject-introspection-1.0)
BuildRequires:	pkgconfig(vapigen)
BuildRequires:	vala-tools
BuildRequires:	gi-docgen
BuildRequires:	python3dist(docutils)

Provides:	rsvg = %{version}-%{release}
Provides:	rsvg-convert = %{version}-%{release}

%description
A library that uses libart and pango to render svg files.

#-----------------------------------------------------------

%package -n %{lib_name}
Summary:	Raph's SVG library
Group:		System/Libraries
Provides:	%{name}%{api_version} = %{version}-%{release}

%description -n %{lib_name}
A library that uses libart and pango to render svg files.

#-----------------------------------------------------------

%package -n %{libnamedev}
Summary:	Libraries and include files for developing with librsvg
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{lib_name} = %{version}-%{release}
Requires:	%{girname} = %{version}-%{release}
Provides:	%{name}%{api_version}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{libnamedev}
This package provides the necessary development libraries and include
files to allow you to develop with librsvg.

#-----------------------------------------------------------

%package -n %{girname}
Summary:	GObject Introspection interface description for %{name}
Group:		System/Libraries
Requires:	%{lib_name} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

#-----------------------------------------------------------

%if %build_mozilla
%package mozilla
Summary:	Mozilla plugin for displaying SVG files
Group:		Networking/WWW
BuildRequires:	xulrunner-devel

%description mozilla
This package provides the necessary development libraries and include
files to allow you to develop with librsvg.
%endif

#-----------------------------------------------------------

%prep
%autosetup -p1 -a2
%if 0%{?bundled_rust_deps}
# Use the bundled deps
mkdir .cargo
cp %{SOURCE3} .cargo/config
%else
# No bundled deps
rm -vrf vendor .cargo Cargo.lock
sed -i Makefile.am -e 's/$(CARGO) --locked/$(CARGO)/'
%cargo_prep
%endif

%if ! 0%{?bundled_rust_deps}
%generate_buildrequires
%cargo_generate_buildrequires
export CARGO="%__cargo"
%endif

%build
%configure \
	--enable-introspection=yes \
	--disable-static \
	--enable-vala
%make_build

%install
%make_install

#we don't want these
find %{buildroot} -name "*.la" -delete

rm -fr %{buildroot}%{_docdir}/librsvg

#-----------------------------------------------------------

%files
%doc AUTHORS NEWS README.md
%license COPYING.LIB
%{_bindir}/rsvg-convert
%{_mandir}/man1/*.1*
%{_datadir}/thumbnailers/librsvg.thumbnailer

%files -n %{lib_name}
%license COPYING.LIB
%{_libdir}/librsvg-%{api_version}.so.%{lib_major}{,.*}
%{_libdir}/gdk-pixbuf-2.0/*/loaders/*.so

%files -n %{girname}
%{_libdir}/girepository-1.0/Rsvg-%{gir_major}.typelib

%files -n %{libnamedev}
%{_libdir}/librsvg-%{api_version}.so
%{_includedir}/librsvg-2.0
%{_libdir}/pkgconfig/*
%{_datadir}/gir-1.0/Rsvg-%{gir_major}.gir
%{_datadir}/vala/vapi/librsvg-2.0.vapi
%{_docdir}/Rsvg-2.0

%if %build_mozilla
%files mozilla
%{_libdir}/mozilla/plugins/*.so
%endif


%changelog
* Thu Aug 31 2023 ns80 <ns80> 2.56.0-1.1.mga9
+ Revision: 1982310
- add upstream patch for CVE-2023-38633 (mga#32210)

* Mon Apr 24 2023 tmb <tmb> 2.56.0-1.mga9
+ Revision: 1954777
- update to 2.56.0
+ neoclust <neoclust>
- New version 2.55.1

* Mon Sep 19 2022 tv <tv> 2.54.5-1.mga9
+ Revision: 1890187
- Fix filelist
+ ovitters <ovitters>
- new version 2.54.5

* Sun Jun 12 2022 tv <tv> 2.54.4-1.mga9
+ Revision: 1864029
- Package doc
- Fix filelist
+ ovitters <ovitters>
- new version 2.54.4
- new version 2.54.3

* Fri May 13 2022 ovitters <ovitters> 2.54.2-1.mga9
+ Revision: 1857853
- new version 2.54.2

* Sat Apr 23 2022 ovitters <ovitters> 2.54.1-1.mga9
+ Revision: 1852800
- new version 2.54.1

* Thu Mar 17 2022 ovitters <ovitters> 2.54.0-1.mga9
+ Revision: 1795118
- new version 2.54.0

* Sat Mar 12 2022 ovitters <ovitters> 2.53.2-1.mga9
+ Revision: 1790532
- new version 2.53.2

* Thu Mar 03 2022 mrambo3501 <mrambo3501> 2.53.1-2.mga9
+ Revision: 1787991
- fixed docutils BR
- rebuild for python-3.10

* Sat Feb 12 2022 ovitters <ovitters> 2.53.1-1.mga9
+ Revision: 1773182
- new version 2.53.1

* Thu Jan 27 2022 mrambo3501 <mrambo3501> 2.53.0-1.mga9
+ Revision: 1769955
- BR python3.9dist(docutils)
- version 2.53.0
- BR gi-docgen
- fix files list

* Mon Jan 10 2022 tv <tv> 2.52.5-1.mga9
+ Revision: 1767444
- 2.52.5

* Sat Jun 05 2021 ovitters <ovitters> 2.50.7-1.mga9
+ Revision: 1729777
- new version 2.50.7

* Tue May 25 2021 ovitters <ovitters> 2.50.6-1.mga9
+ Revision: 1728192
- new version 2.50.6

* Fri Apr 30 2021 ovitters <ovitters> 2.50.5-1.mga9
+ Revision: 1720645
- new version 2.50.5

* Tue Apr 13 2021 ovitters <ovitters> 2.50.4-1.mga9
+ Revision: 1715559
- new version 2.50.4

* Thu Jan 28 2021 ovitters <ovitters> 2.50.3-1.mga8
+ Revision: 1673852
- new version 2.50.3

* Sun Dec 20 2020 wally <wally> 2.50.2-2.mga8
+ Revision: 1661847
- provide rsvg-convert with librsvg

* Fri Nov 20 2020 ovitters <ovitters> 2.50.2-1.mga8
+ Revision: 1648016
- new version 2.50.2

* Tue Oct 13 2020 wally <wally> 2.50.1-2.mga8
+ Revision: 1635499
- drop unused libcroco BR

* Fri Oct 02 2020 ovitters <ovitters> 2.50.1-1.mga8
+ Revision: 1631897
- new version 2.50.1

* Thu Sep 10 2020 ovitters <ovitters> 2.50.0-1.mga8
+ Revision: 1624313
- new version 2.50.0

* Fri Sep 04 2020 ovitters <ovitters> 2.49.5-1.mga8
+ Revision: 1622107
- new version 2.49.5

* Sat Aug 22 2020 ovitters <ovitters> 2.49.4-1.mga8
+ Revision: 1617761
- new version 2.49.4

* Fri Jul 03 2020 ovitters <ovitters> 2.49.3-1.mga8
+ Revision: 1601785
- new version 2.49.3

* Thu Jun 11 2020 ovitters <ovitters> 2.49.2-1.mga8
+ Revision: 1592399
- new version 2.49.2

* Thu Jun 04 2020 ovitters <ovitters> 2.48.7-1.mga8
+ Revision: 1590393
- new version 2.48.7

* Tue Jun 02 2020 ovitters <ovitters> 2.48.6-1.mga8
+ Revision: 1589758
- new version 2.48.6

* Fri May 29 2020 ovitters <ovitters> 2.48.5-1.mga8
+ Revision: 1588967
- new version 2.48.5

* Thu Apr 23 2020 ovitters <ovitters> 2.48.4-1.mga8
+ Revision: 1571416
- new version 2.48.4

* Fri Apr 10 2020 ovitters <ovitters> 2.48.3-1.mga8
+ Revision: 1565939
- new version 2.48.3

* Tue Mar 31 2020 ovitters <ovitters> 2.48.2-1.mga8
+ Revision: 1562793
- new version 2.48.2

* Sat Mar 28 2020 ovitters <ovitters> 2.48.1-1.mga8
+ Revision: 1561292
- new version 2.48.1

* Sat Mar 07 2020 ovitters <ovitters> 2.48.0-1.mga8
+ Revision: 1554532
- new version 2.48.0

* Tue Feb 25 2020 daviddavid <daviddavid> 2.47.1-1.mga8
+ Revision: 1550196
- new version 2.47.1

* Tue Feb 18 2020 tv <tv> 2.47.0-1.mga8
+ Revision: 1542211
- 2.47.0

* Sun Feb 16 2020 umeabot <umeabot> 2.46.0-3.mga8
+ Revision: 1533254
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Sep 20 2019 daviddavid <daviddavid> 2.46.0-2.mga8
+ Revision: 1443978
- backport upstream patch to fix svg rendering in gnome-initial-setup

* Mon Sep 09 2019 ovitters <ovitters> 2.46.0-1.mga8
+ Revision: 1438952
- new version 2.46.0

* Tue Sep 03 2019 tv <tv> 2.45.92-1.1.mga8
+ Revision: 1436822
- simplify: exchange hard to maintain patch byy using bulded rust deps
- use %%autosetup
- drop merged patch
+ daviddavid <daviddavid>
- new version 2.45.92

* Sat Aug 31 2019 tv <tv> 2.45.91-2.mga8
+ Revision: 1436032
- drop useless requires on python

* Sat Aug 17 2019 ovitters <ovitters> 2.45.91-1.mga8
+ Revision: 1429471
- new version 2.45.91

* Sat Aug 03 2019 ovitters <ovitters> 2.45.90-1.mga8
+ Revision: 1426983
- new version 2.45.90

* Mon Jul 22 2019 ovitters <ovitters> 2.45.8-1.mga8
+ Revision: 1423395
- new version 2.45.8
+ wally <wally>
- update URL

* Thu Jul 04 2019 wally <wally> 2.45.6-1.mga8
+ Revision: 1418526
- drop unneeded post/postun (handled by filetriggers)
+ ovitters <ovitters>
- new version 2.45.6

* Sat May 11 2019 martinw <martinw> 2.45.5-3.mga7
+ Revision: 1397211
- fix build with i586 rustc

* Fri May 10 2019 daviddavid <daviddavid> 2.45.5-2.mga7
+ Revision: 1397138
- devel sub-pkg require main pkg

* Sun Mar 10 2019 tmb <tmb> 2.45.5-1.mga7
+ Revision: 1373471
- update to 2.45.5

* Sat Feb 16 2019 ovitters <ovitters> 2.44.13-1.mga7
+ Revision: 1367471
- new version 2.44.13

* Mon Jan 21 2019 ovitters <ovitters> 2.44.12-1.mga7
+ Revision: 1358755
- new version 2.44.12

* Sat Dec 29 2018 ovitters <ovitters> 2.44.11-1.mga7
+ Revision: 1346538
- new version 2.44.11

* Tue Dec 11 2018 ovitters <ovitters> 2.44.10-1.mga7
+ Revision: 1340280
- new version 2.44.10

* Tue Nov 13 2018 ovitters <ovitters> 2.44.9-1.mga7
+ Revision: 1329849
- new version 2.44.9

* Thu Oct 25 2018 ovitters <ovitters> 2.44.8-1.mga7
+ Revision: 1325157
- new version 2.44.8

* Tue Oct 09 2018 ovitters <ovitters> 2.44.7-1.mga7
+ Revision: 1319153
- new version 2.44.7

* Fri Sep 28 2018 ovitters <ovitters> 2.44.6-1.mga7
+ Revision: 1309090
- new version 2.44.6
- new version 2.44.5

* Mon Sep 24 2018 ovitters <ovitters> 2.44.4-1.mga7
+ Revision: 1303519
- new version 2.44.4

* Thu Sep 20 2018 ovitters <ovitters> 2.44.3-1.mga7
+ Revision: 1280126
- new version 2.44.3

* Wed Sep 05 2018 daviddavid <daviddavid> 2.44.2-1.mga7
+ Revision: 1257209
- new version 2.44.2

* Wed Aug 22 2018 ovitters <ovitters> 2.42.7-1.mga7
+ Revision: 1253490
- new version 2.42.7

* Tue Aug 07 2018 ovitters <ovitters> 2.42.6-1.mga7
+ Revision: 1248915
- new version 2.42.6

* Sat Jun 02 2018 ovitters <ovitters> 2.42.5-1.mga7
+ Revision: 1233542
- new version 2.42.5

* Mon May 07 2018 ovitters <ovitters> 2.42.4-1.mga7
+ Revision: 1227562
- new version 2.42.4
+ wally <wally>
- don't own system dirs

* Tue Mar 20 2018 tv <tv> 2.42.3-2.mga7
+ Revision: 1210772
- BR vala-devel
- Package the librsvg Vala bindings

* Tue Mar 20 2018 tv <tv> 2.42.3-1.mga7
+ Revision: 1210765
- fix -ldl underlinking
+ ovitters <ovitters>
- new version 2.42.3
- new version 2.42.2
- new version 2.42.1
+ daviddavid <daviddavid>
- provides rsvg from main package

* Tue Jan 09 2018 ovitters <ovitters> 2.42.0-1.mga7
+ Revision: 1191784
- new version 2.42.0

* Sat Dec 16 2017 wally <wally> 2.41.2-1.mga7
+ Revision: 1182873
- new version 2.41.2
- BR cargo (rust)

* Sat Dec 16 2017 ovitters <ovitters> 2.40.20-1.mga7
+ Revision: 1182744
- new version 2.40.20

* Wed Oct 04 2017 ovitters <ovitters> 2.40.19-1.mga7
+ Revision: 1168747
- new version 2.40.19

* Thu Jul 20 2017 ovitters <ovitters> 2.40.18-1.mga7
+ Revision: 1125431
- new version 2.40.18

* Sat Apr 08 2017 ovitters <ovitters> 2.40.17-1.mga6
+ Revision: 1096095
- new version 2.40.17

* Tue Jul 05 2016 luigiwalser <luigiwalser> 2.40.16-1.mga6
+ Revision: 1039020
- 2.40.16

* Sat Apr 02 2016 ovitters <ovitters> 2.40.15-1.mga6
+ Revision: 997582
- new version 2.40.15

* Sat Jan 16 2016 wally <wally> 2.40.13-2.mga6
+ Revision: 923503
- rebuild to fix gtk-encode-symbolic-svg's (from gtk+3.0-devel) 'Unrecognized image file format' error

* Fri Jan 08 2016 ovitters <ovitters> 2.40.13-1.mga6
+ Revision: 920559
- new version 2.40.13

* Wed Dec 02 2015 ovitters <ovitters> 2.40.12-1.mga6
+ Revision: 907588
- new version 2.40.12

* Thu Oct 08 2015 ovitters <ovitters> 2.40.11-1.mga6
+ Revision: 887888
- new version 2.40.11

* Mon Aug 10 2015 ovitters <ovitters> 2.40.10-1.mga6
+ Revision: 862386
- new version 2.40.10

* Mon Jun 29 2015 wally <wally> 2.40.9-2.mga6
+ Revision: 847717
- add requires for gir pkg to devel pkg

* Sat Jun 20 2015 ovitters <ovitters> 2.40.9-1.mga6
+ Revision: 836325
- new version 2.40.9
- dropped merged patch 1

* Fri Feb 27 2015 ovitters <ovitters> 2.40.7-2.mga5
+ Revision: 817156
- add patch to fix double free

* Mon Feb 16 2015 ovitters <ovitters> 2.40.7-1.mga5
+ Revision: 815134
- new version 2.40.7

* Thu Dec 04 2014 ovitters <ovitters> 2.40.6-1.mga5
+ Revision: 801546
- new version 2.40.6

* Wed Oct 15 2014 umeabot <umeabot> 2.40.5-2.mga5
+ Revision: 739865
- Second Mageia 5 Mass Rebuild

* Mon Oct 13 2014 ovitters <ovitters> 2.40.5-1.mga5
+ Revision: 738322
- new version 2.40.5

* Fri Sep 26 2014 wally <wally> 2.40.4-3.mga5
+ Revision: 724927
- rebuild with new rpm-mageia-setup to generate requires for .typelib files

* Tue Sep 16 2014 umeabot <umeabot> 2.40.4-2.mga5
+ Revision: 681765
- Mageia 5 Mass Rebuild

* Sun Sep 14 2014 ovitters <ovitters> 2.40.4-1.mga5
+ Revision: 675293
- new version 2.40.4

* Mon Aug 18 2014 ovitters <ovitters> 2.40.3-1.mga5
+ Revision: 665200
- new version 2.40.3

* Mon Mar 17 2014 ovitters <ovitters> 2.40.2-1.mga5
+ Revision: 604544
- new version 2.40.2

* Sat Feb 22 2014 tv <tv> 2.40.1-1.mga5
+ Revision: 595433
- there's no more gtk2 support
+ ovitters <ovitters>
- new version 2.40.1
- new version 2.40.0
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sun Aug 18 2013 fwang <fwang> 2.39.0-1.mga4
+ Revision: 467453
- new version 2.39.0

* Sun Jul 28 2013 dams <dams> 2.37.0-1.mga4
+ Revision: 459197
- new version 2.37.0

* Sat Jan 12 2013 umeabot <umeabot> 2.36.4-2.mga3
+ Revision: 358115
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Tue Oct 16 2012 ovitters <ovitters> 2.36.4-1.mga3
+ Revision: 307014
- update group: Graphics/Other
- new version 2.36.4

* Sun Sep 02 2012 ovitters <ovitters> 2.36.3-1.mga3
+ Revision: 287244
- new version 2.36.3

* Sun Aug 19 2012 ovitters <ovitters> 2.36.2-1.mga3
+ Revision: 282396
- new version 2.36.2

* Sat Jun 09 2012 fwang <fwang> 2.36.1-1.mga3
+ Revision: 258371
- update file list
+ ovitters <ovitters>
- new version 2.36.1

* Mon Mar 26 2012 ovitters <ovitters> 2.36.0-1.mga2
+ Revision: 226803
- clean spec
- update file list
- new version 2.36.0

* Mon Mar 05 2012 fwang <fwang> 2.35.2-3.mga2
+ Revision: 218446
- symlink not neede now

* Sun Mar 04 2012 luigiwalser <luigiwalser> 2.35.2-2.mga2
+ Revision: 217727
- restore rsvg and rsvg-view commands with symlinks

* Tue Feb 07 2012 fwang <fwang> 2.35.2-1.mga2
+ Revision: 205677
- update file list
- new version 2.35.2

* Mon Dec 19 2011 wally <wally> 2.35.1-1.mga2
+ Revision: 184571
- new version 2.35.1
- drop P0, fixed upstream

* Tue Dec 13 2011 zezinho <zezinho> 2.35.0-3.mga2
+ Revision: 181423
- Fix including rsvg.h always causing a deprecated warning from fedora

* Mon Nov 14 2011 wally <wally> 2.35.0-2.mga2
+ Revision: 167807
- bump rel due to misbehaving BS
- new version 2.35.0
- enable introspection support and create own subpackage for .typelib
- clean .spec a bit

* Wed Sep 07 2011 fwang <fwang> 2.34.1-1.mga2
+ Revision: 140525
- new version 2.34.1

* Wed Jun 15 2011 dmorgan <dmorgan> 2.34.0-2.mga2
+ Revision: 107984
- Bump release
- Fix file list

* Wed Jun 08 2011 dmorgan <dmorgan> 2.34.0-1.mga2
+ Revision: 101740
- Fix file list
- Fix buildrequires
- New version 2.34.0
+ mikala <mikala>
- Drop mdk macros
- imported package librsvg


* Sun Nov 14 2010 Götz Waschk <waschk@mandriva.org> 2.32.1-1mdv2011.0
+ Revision: 597521
- update to new version 2.32.1

* Mon Sep 27 2010 Funda Wang <fwang@mandriva.org> 2.32.0-1mdv2011.0
+ Revision: 581173
- update to new version 2.32.0

* Mon Aug 09 2010 Funda Wang <fwang@mandriva.org> 2.31.0-2mdv2011.0
+ Revision: 567900
- /usr/bin/rsvg2 is a python script

* Fri Jul 30 2010 Funda Wang <fwang@mandriva.org> 2.31.0-1mdv2011.0
+ Revision: 563261
- New version 2.31.0
- adopt to splitting on gtk and gdk_pixbuff

* Mon May 03 2010 Götz Waschk <waschk@mandriva.org> 2.26.3-1mdv2010.1
+ Revision: 541704
- update to new version 2.26.3

* Tue Mar 30 2010 Götz Waschk <waschk@mandriva.org> 2.26.2-1mdv2010.1
+ Revision: 528963
- update to new version 2.26.2

* Tue Mar 16 2010 Oden Eriksson <oeriksson@mandriva.com> 2.26.0-3mdv2010.1
+ Revision: 520902
- rebuilt for 2010.1

* Sun Oct 04 2009 Funda Wang <fwang@mandriva.org> 2.26.0-2mdv2010.0
+ Revision: 453343
- disable mozilla plugin as it requires xulrunner 1.8

* Mon Mar 16 2009 Götz Waschk <waschk@mandriva.org> 2.26.0-1mdv2009.1
+ Revision: 355970
- update to new version 2.26.0

* Tue Sep 23 2008 Götz Waschk <waschk@mandriva.org> 2.22.3-1mdv2009.0
+ Revision: 287353
- new version
- build with xulrunner
- fix group
- fix license

* Sat Jun 28 2008 Oden Eriksson <oeriksson@mandriva.com> 2.22.2-3mdv2009.0
+ Revision: 229864
- fix build (-lm)

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Mar 04 2008 Götz Waschk <waschk@mandriva.org> 2.22.2-1mdv2008.1
+ Revision: 178712
- new version

* Mon Feb 25 2008 Götz Waschk <waschk@mandriva.org> 2.22.1-1mdv2008.1
+ Revision: 174557
- new version

* Thu Feb 21 2008 Götz Waschk <waschk@mandriva.org> 2.22.0-1mdv2008.1
+ Revision: 173717
- new version

* Sun Jan 20 2008 Götz Waschk <waschk@mandriva.org> 2.20.0-1mdv2008.1
+ Revision: 155297
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Thu Aug 30 2007 Götz Waschk <waschk@mandriva.org> 2.18.2-1mdv2008.0
+ Revision: 75142
- new version

* Tue Aug 21 2007 Götz Waschk <waschk@mandriva.org> 2.18.1-1mdv2008.0
+ Revision: 68239
- new version
- new devel name

* Tue Jul 24 2007 Götz Waschk <waschk@mandriva.org> 2.18.0-1mdv2008.0
+ Revision: 55028
- new version
- fix mozilla plugin build


* Wed Nov 22 2006 Götz Waschk <waschk@mandriva.org> 2.16.1-3mdv2007.0
+ Revision: 86442
- add conflict to fix upgrade

* Wed Nov 22 2006 Colin Guthrie <cguthrie@mandriva.org> 2.16.1-2mdv2007.1
+ Revision: 86240
- Libify the engines for the benefit of x86_64 users

* Fri Nov 03 2006 Götz Waschk <waschk@mandriva.org> 2.16.1-1mdv2007.1
+ Revision: 76075
- another fix for the gtk macros
- fix macros with pkgconfig calls again
- fix gtkbinaryver macro
- Import librsvg

* Fri Nov 03 2006 Götz Waschk <waschk@mandriva.org> 2.16.1-1mdv2007.1
- New version 2.16.1

* Fri Sep 01 2006 Götz Waschk <waschk@mandriva.org> 2.16.0-1mdv2007.0
- New release 2.16.0

* Wed Aug 02 2006 Frederic Crozat <fcrozat@mandriva.com> 2.15.90-3mdv2007.0
- Rebuild with latest dbus

* Mon Jul 31 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.15.90-2
- fix building in autobuilders that install only strictly necessary build deps
- add BuildRequires: libxt-devel

* Fri Jul 28 2006 Götz Waschk <waschk@mandriva.org> 2.15.90-1
- New release 2.15.90

* Fri May 12 2006 Götz Waschk <waschk@mandriva.org> 2.14.4-1mdk
- New release 2.14.4

* Tue Mar 07 2006 Götz Waschk <waschk@mandriva.org> 2.12.7-6mdk
- rebuild for new libgsf

* Mon Feb 27 2006 Frederic Crozat <fcrozat@mandriva.com> 2.12.7-5mdk
- Fortify package uninstall

* Fri Feb 24 2006 Frederic Crozat <fcrozat@mandriva.com> 2.12.7-4mdk
- Use mkrel

* Mon Nov 14 2005 Oden Eriksson <oeriksson@mandriva.com> 2.12.7-3mdk
- rebuilt against openssl-0.9.8a

* Wed Oct 12 2005 Götz Waschk <waschk@mandriva.org> 2.12.7-2mdk
- rebuild for new libgsf

* Mon Oct 10 2005 Götz Waschk <waschk@mandriva.org> 2.12.7-1mdk
- New release 2.12.7

* Sat Oct 08 2005 Frederic Crozat <fcrozat@mandriva.com> 2.12.6-1mdk
- Release 2.12.6

* Sat Oct 08 2005 Frederic Crozat <fcrozat@mandriva.com> 2.12.4-2mdk
- Enforce post dependency
- don't run gdk-pixbuf-query-loaders in postun when upgrading

* Fri Oct 07 2005 Frederic Crozat <fcrozat@mandriva.com> 2.12.4-1mdk
- Release 2.14.4
- Remove patch0 (merged upstream)

* Sat Aug 27 2005 Götz Waschk <waschk@mandriva.org> 2.9.5-2mdk
- replace prereq

* Thu Apr 21 2005 Frederic Crozat <fcrozat@mandriva.com> 2.9.5-1mdk 
- Release 2.9.5 (based on Götz Waschk package)

* Mon Mar 14 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.8.1-5mdk 
- Rebuild with firefox

* Wed Jan 05 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.8.1-4mdk 
- Rebuild with latest howl

* Mon Dec 13 2004 Abel Cheung <deaddog@mandrake.org> 2.8.1-3mdk
- Remove wrong or outdated requirements

* Fri Nov 12 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 2.8.1-2mdk
- add BuildRequires: mozilla-devel

* Wed Oct 20 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.8.1-1mdk
- New release 2.8.1

* Thu Aug 05 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.6.5-2mdk
- biarch support

* Sun May 02 2004 Götz Waschk <waschk@linux-mandrake.com> 2.6.5-1mdk
- don't libtoolize
- fix url
- New release 2.6.5

* Fri Apr 23 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.4-4mdk
- Fix again BuildRequires

* Thu Apr 22 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.4-3mdk
- Fix Buildrequires for documentation generation

* Thu Apr 08 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.4-2mdk
- Rebuild with latest libcroco

* Tue Apr 06 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.6.4-1mdk
- Release 2.6.4 (with Götz Waschk help)

* Tue Apr 06 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 2.4.0-2mdk
- rebuild for gtk+2.4.0 (because of svg pixbuf loader)

